@@ -253,7 +253,7 @@ class Server():
                     log.info(f"成功读取JSON文件 - {file_path}, data is {json_data}")
                     return json_data
                 except json.JSONDecodeError as e:
-                    log.warning("读取JSON文件 - {file_path},错误: JSON解析失败 - {str(e)}，文件: {file_path}")
+                    log.warning(f"读取JSON文件 - {file_path},错误: JSON解析失败 - {str(e)}，文件: {file_path}")
                     return None
                 except Exception as e:
                     log.warning(f"读取JSON文件 - {file_path},错误: 读取文件内容时发生意外 - {str(e)}，文件: {file_path}")
